==> libsoup-2.31.2.tar.bz2: libsoup-2.31.2/libsoup/soup-enum-types.h <==

/* Generated data (by glib-mkenums) */

#ifndef __SOUP_ENUM_TYPES_H__
#define __SOUP_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "soup-address.h" */
GType soup_address_family_get_type (void) G_GNUC_CONST;
#define SOUP_TYPE_ADDRESS_FAMILY (soup_address_family_get_type ())

/* enumerations from "soup-cookie-jar.h" */
GType soup_cookie_jar_accept_policy_get_type (void) G_GNUC_CONST;
#define SOUP_TYPE_COOKIE_JAR_ACCEPT_POLICY (soup_cookie_jar_accept_policy_get_type ())

/* enumerations from "soup-date.h" */
GType soup_date_format_get_type (void) G_GNUC_CONST;
#define SOUP_TYPE_DATE_FORMAT (soup_date_format_get_type ())

/* enumerations from "soup-logger.h" */
GType soup_logger_log_level_get_type (void) G_GNUC_CONST;
#define SOUP_TYPE_LOGGER_LOG_LEVEL (soup_logger_log_level_get_type ())

/* enumerations from "soup-message.h" */
GType soup_http_version_get_type (void) G_GNUC_CONST;
#define SOUP_TYPE_HTTP_VERSION (soup_http_version_get_type ())
GType soup_message_flags_get_type (void) G_GNUC_CONST;
#define SOUP_TYPE_MESSAGE_FLAGS (soup_message_flags_get_type ())

/* enumerations from "soup-message-body.h" */
GType soup_memory_use_get_type (void) G_GNUC_CONST;
#define SOUP_TYPE_MEMORY_USE (soup_memory_use_get_type ())

/* enumerations from "soup-message-headers.h" */
GType soup_message_headers_type_get_type (void) G_GNUC_CONST;
#define SOUP_TYPE_MESSAGE_HEADERS_TYPE (soup_message_headers_type_get_type ())
GType soup_encoding_get_type (void) G_GNUC_CONST;
#define SOUP_TYPE_ENCODING (soup_encoding_get_type ())
GType soup_expectation_get_type (void) G_GNUC_CONST;
#define SOUP_TYPE_EXPECTATION (soup_expectation_get_type ())

/* enumerations from "soup-misc.h" */
GType soup_ssl_error_get_type (void) G_GNUC_CONST;
#define SOUP_TYPE_SSL_ERROR (soup_ssl_error_get_type ())
GType soup_connection_state_get_type (void) G_GNUC_CONST;
#define SOUP_TYPE_CONNECTION_STATE (soup_connection_state_get_type ())

/* enumerations from "soup-socket.h" */
GType soup_socket_io_status_get_type (void) G_GNUC_CONST;
#define SOUP_TYPE_SOCKET_IO_STATUS (soup_socket_io_status_get_type ())

/* enumerations from "soup-status.h" */
GType soup_known_status_code_get_type (void) G_GNUC_CONST;
#define SOUP_TYPE_KNOWN_STATUS_CODE (soup_known_status_code_get_type ())

/* enumerations from "soup-xmlrpc.h" */
GType soup_xmlrpc_error_get_type (void) G_GNUC_CONST;
#define SOUP_TYPE_XMLRPC_ERROR (soup_xmlrpc_error_get_type ())
GType soup_xmlrpc_fault_get_type (void) G_GNUC_CONST;
#define SOUP_TYPE_XMLRPC_FAULT (soup_xmlrpc_fault_get_type ())
G_END_DECLS

#endif /* __SOUP_ENUM_TYPES_H__ */

/* Generated data ends here */

==> libsoup-2.34.0.tar.bz2: libsoup-2.34.0/libsoup/soup-enum-types.h <==

/* Generated data (by glib-mkenums) */

#ifndef __SOUP_ENUM_TYPES_H__
#define __SOUP_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "soup-address.h" */
GType soup_address_family_get_type (void) G_GNUC_CONST;
#define SOUP_TYPE_ADDRESS_FAMILY (soup_address_family_get_type ())

/* enumerations from "soup-cache.h" */
GType soup_cacheability_get_type (void) G_GNUC_CONST;
#define SOUP_TYPE_CACHEABILITY (soup_cacheability_get_type ())
GType soup_cache_response_get_type (void) G_GNUC_CONST;
#define SOUP_TYPE_CACHE_RESPONSE (soup_cache_response_get_type ())
GType soup_cache_type_get_type (void) G_GNUC_CONST;
#define SOUP_TYPE_CACHE_TYPE (soup_cache_type_get_type ())

/* enumerations from "soup-cookie-jar.h" */
GType soup_cookie_jar_accept_policy_get_type (void) G_GNUC_CONST;
#define SOUP_TYPE_COOKIE_JAR_ACCEPT_POLICY (soup_cookie_jar_accept_policy_get_type ())

/* enumerations from "soup-date.h" */
GType soup_date_format_get_type (void) G_GNUC_CONST;
#define SOUP_TYPE_DATE_FORMAT (soup_date_format_get_type ())

/* enumerations from "soup-logger.h" */
GType soup_logger_log_level_get_type (void) G_GNUC_CONST;
#define SOUP_TYPE_LOGGER_LOG_LEVEL (soup_logger_log_level_get_type ())

/* enumerations from "soup-message.h" */
GType soup_http_version_get_type (void) G_GNUC_CONST;
#define SOUP_TYPE_HTTP_VERSION (soup_http_version_get_type ())
GType soup_message_flags_get_type (void) G_GNUC_CONST;
#define SOUP_TYPE_MESSAGE_FLAGS (soup_message_flags_get_type ())

/* enumerations from "soup-message-body.h" */
GType soup_memory_use_get_type (void) G_GNUC_CONST;
#define SOUP_TYPE_MEMORY_USE (soup_memory_use_get_type ())

/* enumerations from "soup-message-headers.h" */
GType soup_message_headers_type_get_type (void) G_GNUC_CONST;
#define SOUP_TYPE_MESSAGE_HEADERS_TYPE (soup_message_headers_type_get_type ())
GType soup_encoding_get_type (void) G_GNUC_CONST;
#define SOUP_TYPE_ENCODING (soup_encoding_get_type ())
GType soup_expectation_get_type (void) G_GNUC_CONST;
#define SOUP_TYPE_EXPECTATION (soup_expectation_get_type ())

/* enumerations from "soup-misc.h" */
GType soup_ssl_error_get_type (void) G_GNUC_CONST;
#define SOUP_TYPE_SSL_ERROR (soup_ssl_error_get_type ())
GType soup_connection_state_get_type (void) G_GNUC_CONST;
#define SOUP_TYPE_CONNECTION_STATE (soup_connection_state_get_type ())

/* enumerations from "soup-requester.h" */
GType soup_requester_error_get_type (void) G_GNUC_CONST;
#define SOUP_TYPE_REQUESTER_ERROR (soup_requester_error_get_type ())

/* enumerations from "soup-socket.h" */
GType soup_socket_io_status_get_type (void) G_GNUC_CONST;
#define SOUP_TYPE_SOCKET_IO_STATUS (soup_socket_io_status_get_type ())

/* enumerations from "soup-status.h" */
GType soup_known_status_code_get_type (void) G_GNUC_CONST;
#define SOUP_TYPE_KNOWN_STATUS_CODE (soup_known_status_code_get_type ())

/* enumerations from "soup-xmlrpc.h" */
GType soup_xmlrpc_error_get_type (void) G_GNUC_CONST;
#define SOUP_TYPE_XMLRPC_ERROR (soup_xmlrpc_error_get_type ())
GType soup_xmlrpc_fault_get_type (void) G_GNUC_CONST;
#define SOUP_TYPE_XMLRPC_FAULT (soup_xmlrpc_fault_get_type ())
G_END_DECLS

#endif /* __SOUP_ENUM_TYPES_H__ */

/* Generated data ends here */
